Debugging and dynamically exploring the application is a common
technique during reverse engineering. Reverse engineers can trace the
execution of the application, snoop sensitive data and modify memory to
alter its behavior.

To complicate the task of analyzing the application dynamically, the
application should implement anti-debugging techniques.
